/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = require("axios");
var axios_mock_adapter_1 = require("axios-mock-adapter");
var chai_1 = require("chai");
var PackageLoader_1 = require("../PackageLoader");
var importGUITemplate_1 = require("./template_test_cases/importGUITemplate");
var importInternalTemplate_1 = require("./template_test_cases/importInternalTemplate");
var packageJsonTemplate_1 = require("./template_test_cases/packageJsonTemplate");
describe('PackageLoader', function () {
    var packageLoader;
    it('should import from internal apl package, depth-first, following the package import order', function (done) {
        var importPackages = [{
                name: 'alexa-gui',
                version: '1.0.0'
            }];
        packageJsonTemplate_1.packageJson['alexa-gui']['document'] = packageJsonTemplate_1.INTERNAL_ALEXA_GUI_SOURCE;
        packageLoader = new PackageLoader_1.PackageLoader(packageJsonTemplate_1.packageJson);
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            chai_1.expect(packageName).to.eql(['alexa-styles-extend', 'anything', 'alexa-styles-classic', 'alexa-gui']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error " + error);
        });
    });
    it('test case 2 should import from internal apl package, following the package import order', function (done) {
        var importPackages = [{
                name: 'alexa-gui',
                version: '1.0.0'
            }, {
                name: 'alexa-style',
                version: '1.0.0'
            }];
        var json = {
            'alexa-gui': {
                document: {
                    type: 'APL',
                    version: '1.0.0'
                }
            },
            'alexa-style': {
                document: {
                    type: 'APL',
                    version: '1.0.0'
                }
            }
        };
        packageLoader = new PackageLoader_1.PackageLoader(json);
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            chai_1.expect(packageName).to.eql(['alexa-style', 'alexa-gui']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error " + error);
        });
    });
    it('should import from predefined apl package, depth-first, following the package import order', function (done) {
        var LAYOUT_URL = 'https://d2na8397m465mh.cloudfront.net/packages/alexa-layouts/1.0.0/document.json';
        var STYLES_URL = 'https://d2na8397m465mh.cloudfront.net/packages/alexa-styles/1.0.0/document.json';
        var VIEWPORT_PROFILES_URL = 'https://d2na8397m465mh.cloudfront.net/packages/alexa-viewport-profiles/1.0.0/document.json';
        var importPackages = [{
                name: 'alexa-layouts',
                version: '1.0.0'
            }];
        var mock = new axios_mock_adapter_1.default(axios_1.default);
        mock.onGet(LAYOUT_URL).reply(200, importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_10);
        mock.onGet(STYLES_URL).reply(200, importInternalTemplate_1.IMPORT_STYLES_TEMPLATE);
        mock.onGet(VIEWPORT_PROFILES_URL).reply(200, importInternalTemplate_1.IMPORT_ALEXA_VIEWPORT_PROFILES);
        packageLoader = new PackageLoader_1.PackageLoader({});
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            chai_1.expect(packageName).to.eql(['alexa-viewport-profiles', 'alexa-styles', 'alexa-layouts']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error " + error);
        });
    });
    it('should be able to import from external apl package', function (done) {
        var URL = 'https://s3.amazonaws.com/apml-authoring-assets/urlTemplate.json';
        var importPackages = [{
                name: 'alexa-gui',
                version: '1.0.0',
                source: URL
            }];
        var mock = new axios_mock_adapter_1.default(axios_1.default);
        mock.onGet(URL).reply(200, importGUITemplate_1.IMPORT_GUI_TEMPLATE);
        packageLoader = new PackageLoader_1.PackageLoader({});
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            chai_1.expect(packageName).to.eql(['alexa-gui']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error " + error);
        });
    });
});
//# sourceMappingURL=PackageLoader.spec.js.map